
######################################################################
######################################################################
### Data Cleaning and preperation for alternative splicing 

# this is using the ballgown packages

######################################################################
######################################################################
### Loading the packages


if (!requireNamespace("BiocManager", quietly = TRUE)){
  install.packages("BiocManager")
BiocManager::install()
}

if (!require("ballgown")) {
  BiocManager::install("ballgown")
  library(ballgown)
}

if (!require("devtools")) {
  install.packages("devtools", dependencies = TRUE)
  library(devtools)
}

if (!require("RSkittleBrewer")) {
  devtools::install_github('alyssafrazee/RSkittleBrewer')
  library(RSkittleBrewer)
}

if (!require("genefilter")) {
  install.packages("genefilter", dependencies = TRUE)
  library(genefilter)
}

if (!require("dplyr")) {
  install.packages("dplyr", dependencies = TRUE)
  library(dplyr)
}

if (!require("tidyr")) {
  install.packages("tidyr", dependencies = TRUE)
  library(tidyr)
}

######################################################################
######################################################################
### Loading in the data


# Getting the phenotype data 

sample_to_condition <- read.table('Data/SraRunTable.txt', header = TRUE,
                                  sep = '\t')

sample_to_condition <- sample_to_condition %>%
  dplyr::select(sample = Sample_Name, treatment = experimental_treatment) %>%
  unique


# Creating the ballgown object

bg <- ballgown(dataDir = "Data/Alternative_Splicing",samplePattern = "GSM", meas = 'all', verbose = T)

# getting gene names 

Gene_names <- getGenes("Data/First_data.gtf",structure(bg)$trans,UCSC = F,attribute="gene_name")

gnames_first <- lapply(Gene_names, function(x) x[1])

ballgown::expr(bg)$trans$gene_name <- gnames_first

# Can filter genes with low abundance in this case filtering transcripts with a variance 
# across samples less than 3 

bg_filter <- subset(bg,"rowVars(texpr(bg)) > 3",genomesubset =T)

# adding the phenotype data to ballgown object 

pData(bg_filter) <- sample_to_condition


######################################################################
######################################################################
### Second data set with host type

# Getting the phenotype data for seconds dat set 

sample_to_condition_2 <- read.table('Data/SraRunTable_2.txt', header = T,
                                    sep = '\t')

# removing same sample we removed from the gene expression analysis now based upon alt PCA

sample_to_condition_2 <- sample_to_condition_2 %>%
  dplyr::select(sample = Sample_Name, Foundress_no = foundress_number, host_type = host_type_given) %>%
  unique() %>%
  # PAPER HAS JUST THE FIRST SAMPLE REMOVED
  filter(sample != "GSM1915235") %>%
  #filter(sample != "GSM1915247") %>%
  #filter(sample != "GSM1915215") %>%
  mutate(path = file.path("Data/Alternative_Splicing_2",sample))
 

sample_to_condition_2$Foundress_no <- as.character(sample_to_condition_2$Foundress_no)

sample_to_condition_2$host_type <-  gsub("none","control",sample_to_condition_2$host_type)

sample_to_condition_2_host <- sample_to_condition_2 %>%
                filter(host_type != "control") %>%
                mutate(path = file.path("Data/Alternative_Splicing_2/",sample))

sample_to_condition_2_parasitised_host_none <- sample_to_condition_2 %>%
  filter(host_type != "fresh") %>%
  mutate(path = file.path("Data/Alternative_Splicing_2/",sample))

sample_to_condition_2_fresh_none <- sample_to_condition_2 %>%
  filter(host_type != "previously parasitised") %>%
  mutate(path = file.path("Data/Alternative_Splicing_2/",sample))


# Creating the ballgown object 

bg_2 <- ballgown(samples = sample_to_condition_2$path,meas = 'all' )

bg_2_host <- ballgown(samples = sample_to_condition_2_host$path,meas = "all")

bg_2_par_non <- ballgown(samples = sample_to_condition_2_parasitised_host_none$path, meas = "all")

bg_2_fresh_non <- ballgown(samples = sample_to_condition_2_fresh_none$path , meas = "all")

# Getting the gene names

Gene_names <- getGenes("Data/Second_data.gtf",structure(bg_2)$trans,UCSC = F , attribute = "gene_name")

gnames_first <- lapply(Gene_names, function(x) x[1])

ballgown::expr(bg_2)$trans$gene_name <- gnames_first

Gene_names <- getGenes("Data/Second_data.gtf",structure(bg_2_host)$trans,UCSC = F , attribute = "gene_name")

gnames_first <- lapply(Gene_names, function(x) x[1])

ballgown::expr(bg_2_host)$trans$gene_name <- gnames_first

Gene_names <- getGenes("Data/Second_data.gtf",structure(bg_2_par_non)$trans,UCSC = F , attribute = "gene_name")

gnames_first <- lapply(Gene_names, function(x) x[1])

ballgown::expr(bg_2_par_non)$trans$gene_name <- gnames_first

Gene_names <- getGenes("Data/Second_data.gtf",structure(bg_2_fresh_non)$trans,UCSC = F , attribute = "gene_name")

gnames_first <- lapply(Gene_names, function(x) x[1])

ballgown::expr(bg_2_fresh_non)$trans$gene_name <- gnames_first

# Can filter genes with low abundance in this case filtering transcripts with a variance 
# across samples less than 5 

bg_filter_2 <- subset(bg_2,"rowVars(texpr(bg_2)) > 3",genomesubset =T)

bg_filter_2_host <- subset(bg_2_host,"rowVars(texpr(bg_2_host)) > 5",genomesubset =T)

bg_filter_2_par_non <- subset(bg_2_par_non , "rowVars(texpr(bg_2_par_non)) > 5",genomesubset =T)

bg_filter_2_fresh_non <- subset(bg_2_fresh_non , "rowVars(texpr(bg_2_fresh_non)) > 5",genomesubset =T)

# adding the phenotype data to ballgown object

Get_replicates <- function(sample_cond){
  
  levels_1 <- unique(sample_cond[,2])
  
  for(i in 1:nrow(sample_cond)){
    
    if(sample_cond[i,2] == levels_1[1]){
      
      sample_cond$replicates[i] <- paste0(levels_1[1],sample_cond[i,3])
      
    }
    
    if(sample_cond[i,2] == levels_1[2]){
      
      sample_cond$replicates[i] <- paste0(levels_1[2],sample_cond[i,3])
      
    }
    
  }
  
  levels_2 <- unique(sample_cond$replicates)
  
  Count_vec <- c(1,1,1,1,1,1)
  
  for(j in 1:nrow(sample_cond)){
    
    for(k in 1:length(levels_2)){
      
      if(sample_cond$replicates[j] == levels_2[k]){
        
        sample_cond$replicates[j] <- paste(sample_cond$replicates[j],Count_vec[k],sep = "_")
      
      Count_vec[k] <- Count_vec[k]+ 1
      
      }
    }
    
  }
  
  sample_cond$replicates <- as.factor(sample_cond$replicates)
  
  return(sample_cond)
}
                       
                      
#sample_to_condition_2 <- Get_replicates(sample_to_condition_2)                      


pData(bg_filter_2) <- sample_to_condition_2[,c(1,2,3)]

sample_to_condition_2_host <- droplevels(sample_to_condition_2_host)

pData(bg_filter_2_host) <- sample_to_condition_2_host[,c(1,2,3)]

sample_to_condition_2_parasitised_host_none <-droplevels(sample_to_condition_2_parasitised_host_none)

pData(bg_filter_2_par_non) <- sample_to_condition_2_parasitised_host_none[,c(1,2,3)]

sample_to_condition_2_fresh_none <- droplevels(sample_to_condition_2_fresh_none)

pData(bg_filter_2_fresh_non) <- sample_to_condition_2_fresh_none[,c(1,2,3)]









