
######################################################################
######################################################################
### Combinign the results for dif gene expression and transcript 
### expression to identify alternative splicing.  


######################################################################
######################################################################
### Loading packages

if (!require("dplyr")) {
  install.packages("dplyr", dependencies = TRUE)
  library(dplyr)
}

if (!require("tidyr")) {
  install.packages("tidyr", dependencies = TRUE)
  library(tidyr)
}

if (!require("rtracklayer")) {
  source("http://bioconductor.org/bioclite.R")
  bioclite('rtracklayer')
  library(rtracklayer)
}

if (!require("xtable")) {
  install.packages("xtable", dependencies = TRUE)
  library(xtable)
}

######################################################################
######################################################################
### Loading in the data for data 2

# The differentially expressed genes with host as treatment

DE_Genes_Host <- read.table(file = "Data/DE_Genes_host",header = T,stringsAsFactors = T)

# All the info for the genes with differentially expressed transcripts

Ballgow_Genes <- read.table(file = "Data/Alternative_splicing_2_transcripts_host",header = T)

# Multi trans is the genes with more then one identified transcript 

Multi_transcript_genes <- read.table(file = "Data/Genes_with_multi_trans",header = T)

######################################################################
######################################################################
### Getting genes that  are spliced but not DE expressed and 
### identifying relationship between DE and altsplice is

# getting genes that are spliced but not differentially expressed 

# First remove genes identified as being differentially expressed

Splice_Not_DE <- Ballgow_Genes[!(Ballgow_Genes$geneNames %in% DE_Genes_Host$target_id),]

# Remove genes that only have one known transcript. As that would be just differential gene expression and 
# we already did that with the sleuth pipline
# Can see differential expression in one transcript but not in the others

Splice_Not_DE <- Splice_Not_DE[Splice_Not_DE$id %in% Multi_transcript_genes$t_id,]


Multi_transcript_genes <- Multi_transcript_genes %>%
  inner_join(Ballgow_Genes, by = c("t_id" = "id")) 
  

DE_Only <- DE_Genes_Host[!(DE_Genes_Host$target_id %in% Multi_transcript_genes$geneNames),]

DE_and_Splice <- DE_Genes_Host[DE_Genes_Host$target_id %in% Multi_transcript_genes$geneNames,]

# It looks like this GFF section is not needed have a look over tomorrow 
# Sorting out a table with the annotation information 

#GFF <- import.gff("~/Dropbox/Nasonia_RNA/GCF_000002325.3_Nvit_2.1_genomic.gff")

#Data <- data.frame("gene" = GFF$gene, 'product' = GFF$product)

#Data <- Data[complete.cases(Data),]

#Data <- unique.data.frame(Data) %>% 
#  filter(!grepl("transcript|isoform",product))


#Data$gene <- as.factor(Data$gene)

#Splice_Not_DE$geneNames <- as.factor(Splice_Not_DE$geneNames)


#DE_Genes_Host <- DE_Genes_Host %>%
#  inner_join(Data , by=c('target_id'='gene'))


#Splice_Not_DE <- Splice_Not_DE %>%
#  inner_join(Data , by=c('geneNames' = 'gene'))


### Writing these tables out 

write.table(DE_Only,"Data/DE_genes_only",
            sep = "\t",col.names = T,row.names = F)

write.table(Splice_Not_DE,"Data/Spliced_no_DE",
            sep = "\t",col.names = T,row.names = F)

write.table(DE_and_Splice,"Data/DE_and_Splice",
            sep = "\t" , col.names = T , row.names = F)


# writeing latex table

print(xtable(head(DE_Genes_Host[,-2], n = 20)),include.rownames=FALSE , auto = T,
      label= "tabel1" ,align = 'c')

print(xtable(head(Splice_Not_DE[,-2], n = 20)),include.rownames=FALSE , auto = T,
      label= "tabel1" ,align = 'c')

