
######################################################################
######################################################################
###  Differential Expression


######################################################################
######################################################################
### Getting in the data


source("Scripts/RNA_Seq_Data_cleaning_prep.R")

######################################################################
######################################################################
### Creating the Sleuth Models and liklihood ratio test for Genes

# the full model fits a measurment error model technical variance estimation

Nas_sleuth_obj <- sleuth_fit(Nas_sleuth_obj,~treatment,'full')

# Reduced model fit

Nas_sleuth_obj <- sleuth_fit(Nas_sleuth_obj,~1,'reduced')

# Running the liklihood ratio test

Nas_sleuth_obj <- sleuth_lrt(Nas_sleuth_obj,'reduced','full')

# Viewing the model

models(Nas_sleuth_obj)

# Visulise results

sleuth_live(Nas_sleuth_obj)

######################################################################
######################################################################
### Getting the Results

# Porducing a results table

Nas_Results_table <- sleuth_results(Nas_sleuth_obj,'reduced:full','lrt',show_all = F)

# Seeing which are significant by Q value

Nas_significant_table <- Nas_Results_table %>%
                         filter(qval<= 0.05)

# There are no significant results matching the result found by the study however am still to look at diffrential 
# Transcript expression (potentiall use the which_var obs_tpm for the sleuth fit)

######################################################################
######################################################################
### Data set two

# the full model fits a measurment error model technical variance estimation

Nas_sleuth_obj_2 <- sleuth_fit(Nas_sleuth_obj_2,~foundress_no + host_type,'full')

# Reduced model fit

Nas_sleuth_obj_2 <- sleuth_fit(Nas_sleuth_obj_2,~1,'reduced')

# Model with just foundress no

Nas_sleuth_obj_2 <- sleuth_fit(Nas_sleuth_obj_2,~foundress_no,"foundress")

# Model with just host type

Nas_sleuth_obj_2 <- sleuth_fit(Nas_sleuth_obj_2,~host_type, "host")

# Running the liklihood ratio test

Nas_sleuth_obj_2 <- sleuth_lrt(Nas_sleuth_obj_2,'reduced','full')

Nas_sleuth_obj_2 <- sleuth_lrt(Nas_sleuth_obj_2,'reduced','foundress')

Nas_sleuth_obj_2 <- sleuth_lrt(Nas_sleuth_obj_2,'reduced','host')

# Viewing the model

models(Nas_sleuth_obj_2)

######################################################################
######################################################################
### Getting the Results data set 2

# Producing a results table

Nas_Results_table_2 <- sleuth_results(Nas_sleuth_obj_2,'reduced:full','lrt',show_all = F)

Nas_Results_table_2_foundress <- sleuth_results(Nas_sleuth_obj_2,'reduced:foundress','lrt',show_all = F)

Nas_Results_table_2_host <- sleuth_results(Nas_sleuth_obj_2,'reduced:host','lrt',show_all = F)

# Seeing which are significant by Q value

Nas_significant_table_2 <- Nas_Results_table_2 %>%
  filter(qval<= 0.05)

Nas_significant_table_2_foundress <- Nas_Results_table_2_foundress %>%
  filter(qval<= 0.05)

Nas_significant_table_2_host <- Nas_Results_table_2_host %>%
  filter(qval<= 0.05)

# Writing the table

write.table(Nas_significant_table_2_host,"Data/DE_Genes_host",sep = "\t",col.names = T,row.names = F)


# Visulise results

sleuth_live(Nas_sleuth_obj_2)

