
######################################################################
######################################################################
### Figures alternative splicing 


######################################################################
######################################################################
### Reading in the data 

source("Scripts/Alternative_splicing_analysis.R")
source("Scripts/Plot_functions.R")

######################################################################
######################################################################
### Loading in the packages


if (!require("ggplot2")) {
  install.packages("ggplot2", dependencies = TRUE)
  library(ggplot2)
}

if (!require("ggfortify")) {
  install.packages("ggfortify", dependencies = TRUE)
  library(ggfortify)
}

if (!require("reshape2")) {
  install.packages("reshape2", dependencies = TRUE)
  library(reshape2)
}

if (!require("gplots")) {
  install.packages("gplots", dependencies = TRUE)
  library(gplots)
}

if (!require("pheatmap")) {
  install.packages("pheatmap", dependencies = TRUE)
  library(pheatmap)
}

if (!require("RColorBrewer")) {
  install.packages("RColorBrewer", dependencies = TRUE)
  library(RColorBrewer)
}

if (!require("gridExtra")) {
  install.packages("gridExtra", dependencies = TRUE)
  library(gridExtra)
}

######################################################################
######################################################################
### PCA for general coverage for transcripts for all libraries
### Old idea (Plotting the PCA for intron usage based up host treatment
# trying to recreate the pca using the ggplot and ggfortify packages as easier to view where treatment comes 
# into play.  Currently using the autoplot funciton but will move into ggplot to get more info on the
# different conditions


new_position_theme <- theme(legend.position = c(0.80, 0.80) , 
                            panel.border = element_blank(), panel.grid.major = element_blank(),
                            panel.grid.minor = element_blank(), panel.background = element_blank(),
                            axis.line = element_line(colour = "grey"))


bg_cov <- as.data.frame(texpr(bg_filter,meas = "cov"))

names(bg_cov) <- sampleNames(bg_filter)

bg_cov <- t(bg_cov)


 PCA_data1 <- autoplot(prcomp(bg_cov), data = pData(bg_filter) , colour="treatment" ,frame = F ,size=3) +
   ggtitle('Transcript data from 2018 study (Head)') + 
   theme(plot.title = element_text(lineheight=.8,hjust = 0.5, size = 15),legend.position="none" ,
         panel.border = element_blank(), panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), panel.background = element_blank(),
         axis.line = element_line(colour = "grey"))

 
 ggsave('Figures/PCA_data_1_altsplice.pdf',plot = PCA_data1 ,device = 'pdf')
 
 
pdf("Figures/PCA_data_1_altsplice.pdf")
PCA_data1
dev.off()
 
 # Plot for the second data set

bg_2_cov <- as.data.frame(texpr(bg_filter_2,meas = "cov"))

names(bg_2_cov) <- sampleNames(bg_filter_2)

bg_2_cov <- t(bg_2_cov)

PCA_data2 <- autoplot(prcomp(bg_2_cov), data = pData(bg_filter_2), colour="host_type", frame = F,
         label=F , size=3) +
  ggtitle('Transcript data from 2015 study (Whole body)') + 
  theme(plot.title = element_text(lineheight=.8,hjust = 0.5, size = 15), legend.position="none" ,
        panel.border = element_blank(), panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), panel.background = element_blank(),
        axis.line = element_line(colour = "grey")) 
  

pdf("Figures/PCA_data_2_altsplice.pdf")
PCA_data2 
dev.off()

### Joining the two plots

Joint_Alternative_splice_plot <- grid.arrange(PCA_data1,PCA_data2)

ggsave('Figures/Joint_AltSplice_plot.png',plot = Joint_Alternative_splice_plot ,device = 'png',
       scale = 1.4)


pdf('Figures/Joint_AltSplice_plot.pdf')
Joint_Alternative_splice_plot
dev.off()

######################################################################
######################################################################
### Heat map to view correlation between treatment gorups as if PCA 
### wasnt enough

# data set 1 
corelation <- as.data.frame(texpr(bg_filter,meas = "FPKM"))

values <- pData(bg_filter)

# getting the names

Sort_names_1 <- function(values){
  
  values$treatment <- as.character(values$treatment)
  values$name <- NA
  rows <- nrow(values)
  one <- 1
  five <- 1
  ten <- 1
  
  for ( i in 1:rows){
    if(values$treatment[i]=="Single foundress"){
      values$name[i] <- paste("Single foundress_",one,sep = "")
      one <- one + 1
    }
    if(values$treatment[i]=="Five foundress"){
      values$name[i] <- paste("Five foundress_",five,sep = "")
      five <- five + 1
    }
    if(values$treatment[i]=="Ten foundress"){
      values$name[i] <- paste("Ten foundress_",ten,sep = "")
      ten <- ten + 1
    }
    
  }
  return(values)
}

values <- Sort_names_1(values)

# getting the coreelation matrix

names(corelation) <- values$name

a <- cor(corelation)

# getting the annotation info 

treatment <- values[,2]

treatment <- as.data.frame(treatment)

names(treatment) <- "treatment"

rownames(treatment) <- values$name

# heatmap

Heatmap_data1 <- pheatmap(a , annotation_col = treatment, treeheight_row = 0,
         fontsize_row = 7,fontsize_col = 7 )

pdf("Figures/Heatmap_data1.pdf")
Heatmap_data1
dev.off()

### data set 2 
corelation_2 <- as.data.frame(texpr(bg_filter_2,meas = "FPKM"))

# just getting the ids which were differentially transcribed

corelation_2 <- corelation_2[stat_results_transcript_2_host$id,]

# sorting out the data based on treatment

values <- pData(bg_filter_2)

Sort_names <- function(values){
  
  values$host_type <- as.character(values$host_type)
  values$name <- NA
  rows <- nrow(values)
  fresh <- 1
  prev <- 1
  none <- 1
  
  for ( i in 1:rows){
    if(values$host_type[i]=="fresh"){
      values$name[i] <- paste("Fresh_",fresh,sep = "")
      fresh <- fresh + 1
    }
    if(values$host_type[i]=="none"){
      values$name[i] <- paste("Control_",none,sep = "")
      none <- none + 1
    }
    if(values$host_type[i]=="previously parasitised"){
      values$name[i] <- paste("Pre.parasitised_",prev,sep = "")
      prev <- prev + 1
  }
  
  }
  return(values)
}
  

values <- Sort_names(values = values)
  
names(corelation_2) <- values$name

a <- cor(corelation_2)

treatment <- values[,3]

treatment <- as.data.frame(treatment)

names(treatment) <- "treatment"

rownames(treatment) <- values$name

Heatmap_data2 <- pheatmap(a , annotation_col = treatment, treeheight_row = 0,
         fontsize_row = 7,fontsize_col = 7 )

pdf("Figures/Heatmap_data2.pdf")
Heatmap_data2
dev.off()

# Getting the transcript gene id information

transcript_gene_table = data.frame(t_id = bg_2@expr$trans$t_id , t_name = bg_2@expr$trans$t_name)

write.table(transcript_gene_table , col.names = T , row.names = F , file = 'Data/T_id_to_T_Name.txt')

######################################################################
######################################################################
### Genes that are differently splice 

# MSTRG.5493 is for LOC100117537 a histone glutamine methyltranseferase

Transcript_mean_plot_c <- plotMeans("MSTRG.5493",gown = bg_filter_2,groupvar = 'host_type', meas = "ucount"
                             ,colorby = "exon" ,groupname = "control" , labelTranscripts = T)

Transcript_mean_plot_f <- plotMeans("MSTRG.5493",gown = bg_filter_2,groupvar = 'host_type', meas = "ucount"
                                    ,colorby = "exon" ,groupname = "fresh" , labelTranscripts = T)

Transcript_mean_plot_p <- plotMeans("MSTRG.5493",gown = bg_filter_2,groupvar = 'host_type', meas = "ucount"
                                    ,colorby = "exon" ,groupname = "previously parasitised", labelTranscripts = T)


 PLot_means_2("MSTRG.5493",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM",
                          TITLE = "LOC100117537 ",colorby = "transcript" ,groupname = "control" , labelTranscripts = T)

 PLot_means_2("MSTRG.5493",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM",
              TITLE = "LOC100117537 " ,colorby = "transcript" ,groupname = "fresh" , labelTranscripts = T)

 PLot_means_2("MSTRG.5493",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM",
              TITLE = "LOC100117537 ",colorby = "transcript" ,groupname = "previously parasitised", labelTranscripts = T)




  pdf("Figures/histone_glutimite_methyltransferase.pdf")
Transcript_mean_plot_c
Transcript_mean_plot_f
Transcript_mean_plot_p
dev.off()


# MSTRG.7008 is for LOC100117441 which is involved in snRNA 3'end processing and given a transgenerational
# preprint abount snRNA transgeneratinoal inheritance might be worth talking about rrp45

Transcript_mean_plot_snRNA_c <- plotMeans("MSTRG.7008",gown = bg_filter_2,groupvar = 'host_type', meas = "ucount"
                                          ,colorby = "exon" ,groupname = "control")

Transcript_mean_plot_snRNA_c <- PLot_means_2("MSTRG.7008",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
                                          ,colorby = "transcript" ,groupname = "control", TITLE = 'LOC100117441')

Transcript_mean_plot_snRNA_f <- plotMeans("MSTRG.7008",gown = bg_filter_2,groupvar = 'host_type', meas = "ucount"
                                          ,colorby = "exon" ,groupname = "fresh")

Transcript_mean_plot_snRNA_f <- PLot_means_2("MSTRG.7008",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
                                             ,colorby = "transcript" ,groupname = "fresh", TITLE = 'LOC100117441')

Transcript_mean_plot_snRNA_p <- plotMeans("MSTRG.7008",gown = bg_filter_2,groupvar = 'host_type', meas = "ucount"
                                          ,colorby = "exon" ,groupname = "previously parasitised")

Transcript_mean_plot_snRNA_p <- PLot_means_2("MSTRG.7008",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
                                             ,colorby = "transcript" ,groupname = "previously parasitised", TITLE = 'LOC100117441')


# LOC100116741 is the REST corepressor 3 and found to have one isoform significantly more highly expressed due to 
# oviposition it only has two isoforms

Transcript_mean_plot_Rest_corep3_c <- plotMeans("MSTRG.9564",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
                                          ,colorby = c('transcript',"exon"),groupname = "control",
                                          labelTranscripts = T)

Transcript_mean_plot_Rest_corep3_f <- PLot_means_2("MSTRG.9564",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
                                                   ,colorby = c('transcript',"exon") ,groupname = "control",
                                                   labelTranscripts = T , TITLE = 'LOC100116741')

Transcript_mean_plot_Rest_corep3_f <- plotMeans("MSTRG.9564",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
                                          ,colorby = c('transcript',"exon") ,groupname = "fresh",
                                          labelTranscripts = T )

Transcript_mean_plot_Rest_corep3_f <- PLot_means_2("MSTRG.9564",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
                                                ,colorby = c('transcript',"exon") ,groupname = "fresh",
                                                labelTranscripts = T , TITLE = 'LOC100116741')



Transcript_mean_plot_Rest_corep3_p <- plotMeans("MSTRG.9564",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
                                          ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
                                          labelTranscripts = T )


Transcript_mean_plot_Rest_corep3_p <- PLot_means_2("MSTRG.9564",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
                                                ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
                                                labelTranscripts = T , TITLE = 'LOC100116741')



# PLot for transformer 2 MSTRG.6429 LOC100116671

PLot_means_2("MSTRG.6429",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'Transformer 2')


PLot_means_2("MSTRG.6429",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'Transformer 2')

PLot_means_2("MSTRG.6429",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'Transformer 2')


# Plot for LOC103315501 which is MSTRG.353 , CREB like binding protein

PLot_means_2("MSTRG.353",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'CREB like binding protein')


PLot_means_2("MSTRG.353",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'CREB like binding protein')

PLot_means_2("MSTRG.353",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'CREB like binding protein')

# Plot for LOC100119862 which is MSTRG.3279 , digestive cysteine proteinase this is in the same class as 
# the hedhog proteins as in sonic heghog

PLot_means_2("MSTRG.3279",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'Digestive cytesine proteinase')


PLot_means_2("MSTRG.3279",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'Digestive cytesine proteinase')

PLot_means_2("MSTRG.3279",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'Digestive cytesine proteinase')

# Plot for LOC100678025 which is MSTRG.5676 , mitochondrial cardiolipin hydrolase involved in PIWI 
# interacting RNA and definitly worth looking at and writing about 

PLot_means_2("MSTRG.5676",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'Mitochondrial cardiolipin hydrolase')


PLot_means_2("MSTRG.5676",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'Mitochondrial cardiolipin hydrolase')

PLot_means_2("MSTRG.5676",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'Mitochondrial cardiolipin hydrolase')

# Plot for LOC100116784 which is MSTRG.11632 , exosome complex component RRP42 processing of stable
# and mature snRNA and other types

PLot_means_2("MSTRG.11632",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'RRP42')


PLot_means_2("MSTRG.11632",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'RRP42')

PLot_means_2("MSTRG.11632",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'RRP42')


# Plot for LOC100113663 which is MSTRG.8241, serine-arginine protein 55 which is a splicing factor

PLot_means_2("MSTRG.8241",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'serine-arginine protein 55')


PLot_means_2("MSTRG.8241",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'serine-arginine protein 55')

PLot_means_2("MSTRG.8241",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'serine-arginine protein 55')

# Plot for LOC100119193 which is MSTRG.63, RNA-binding protein squid like shows increased expression
# during oviposition

PLot_means_2("MSTRG.63",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'RNA-binding protein squid like')


PLot_means_2("MSTRG.63",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'RNA-binding protein squid like')

PLot_means_2("MSTRG.63",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'RNA-binding protein squid like')


# Plot for LOC100122901 whcih is MSTRG.3040, apoptotic chromatin condensation inducer in the nucleus

PLot_means_2("MSTRG.3040",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'apoptotic chromatin condensation inducer')


PLot_means_2("MSTRG.3040",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'apoptotic chromatin condensation inducer')

PLot_means_2("MSTRG.3040",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'apoptotic chromatin condensation inducer')


# Plot for dsx which is MSTRG.7540 , this is double sex

PLot_means_2("MSTRG.7540",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'dsx')


PLot_means_2("MSTRG.7540",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'dsx')

PLot_means_2("MSTRG.7540",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'dsx')

# Plot for rffl which is MSTRG.3666 , proeing ubiquination

PLot_means_2("MSTRG.3666",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'Rffl')


PLot_means_2("MSTRG.3666",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'Rffl')

PLot_means_2("MSTRG.3666",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'Rffl')


# Plot for LOC100121492 which is MSTRG.1314, this is an uncharacterised LOC which came up as sex 
# pigmentation GO term along with regulation of RNAPol2 and sex differentiation

PLot_means_2("MSTRG.1314",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100121492')


PLot_means_2("MSTRG.1314",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100121492')

PLot_means_2("MSTRG.1314",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100121492')

# Plot for LOC100117953 which is MSTRG.6466 , this is Caspase Nc which has the go term for ectopic germ
# cell programmed cell death

PLot_means_2("MSTRG.6466",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'Capase Nc')


PLot_means_2("MSTRG.6466",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'Capase Nc')

PLot_means_2("MSTRG.6466",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'Capase Nc')

# Plot for LOC100121847 which is MSTRG.12093, this is putative phosphatidate phosphatase which has the 
# PAP2, wunen subfamily. Most likely a family of membrane associated phosphatidic acid phosphatases. 
# Wunen is a drosophila protein expressed in the central nervous system, which provides repellent activity 
# towards primordial germ cells (PGCs), controls the survival of PGCs and is essential in the migration 
# process of these cells towards the somatic gonadal precursors. ### LOOKS VERY COOL

PLot_means_2("MSTRG.12093",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'PREDICTED putative phosphatidate phosphatase')


PLot_means_2("MSTRG.12093",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'PREDICTED putative phosphatidate phosphatase')

PLot_means_2("MSTRG.12093",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'PREDICTED putative phosphatidate phosphatase')


# plot LOC100120768 "MSTRG.12197" RNA-binding protein squid important for splicng and oocyte devo



# Plot LOC100119779 which is MSTRG.1926 , it is the 'Pho' gene in drosophila 
# https://www.uniprot.org/uniprot/Q8ST83 important chromsoome regulatory chromatin

PLot_means_2("MSTRG.1926",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100119779')


PLot_means_2("MSTRG.1926",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100119779')

PLot_means_2("MSTRG.1926",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100119779')

# plot for LOC100680480  whoich is MSTRG.5659, which when blasted one of drosophila ejaculartory bulb 
# protein isoforms came up as the top hit 

PLot_means_2("MSTRG.5659",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100680480')


PLot_means_2("MSTRG.5659",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100680480')

PLot_means_2("MSTRG.5659",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100680480')


# Plot for the alt splicing of LOC100113853 is MSTRG.12390, MAP kinase-interacting serine/threonine-protein kinase 1
# this is involved with sperm motility with changing from type B to C motility requires calcium for
# activation 

PLot_means_2("MSTRG.12390",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100113853 ')


PLot_means_2("MSTRG.12390",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100113853')

PLot_means_2("MSTRG.12390",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100113853 ')


# Plot for alt spling of LOC100120769 MSTRG.5334, this is another MAP Kinase which is involved with sperm 
# motility for calcium-dependent protein serine/threonine kinase activity

PLot_means_2("MSTRG.5334",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100120769')


PLot_means_2("MSTRG.5334",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100120769')

PLot_means_2("MSTRG.5334",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100120769')

# PLot for LOC103315501, MSTRG.353, CREB binding protein is a key transcription factor and has protein kinase and
# regulated histone acetylation lots of thinks 

PLot_means_2("MSTRG.353",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC103315501')


PLot_means_2("MSTRG.353",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC103315501')

PLot_means_2("MSTRG.353",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC103315501')

# Plot for LOC100119158 ,MSTRG.1910 , has a PP2Cc; Serine/threonine phosphatases, family 2C, 
# catalytic domain

PLot_means_2("MSTRG.1910",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100119158')


PLot_means_2("MSTRG.1910",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100119158')

PLot_means_2("MSTRG.1910",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100119158')



# Plot for LOC100117454, MSTRG.671, calcium/calmodulin-dependent protein kinase type 1 imporntant 
# for sperm motility

PLot_means_2("MSTRG.671",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100117454')


PLot_means_2("MSTRG.671",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100117454')

PLot_means_2("MSTRG.671",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100117454')



# Plot for P38mapk, MSTRG.2138, mitogen serine threnoine protein kinase

PLot_means_2("MSTRG.2138",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'P38mapk')

PLot_means_2("MSTRG.2138",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'P38mapk')

PLot_means_2("MSTRG.2138",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'P38mapk')


# There are even more kinase spliced genes though need to determine who relates to difference between
# Ca2 dependent and sperm motility and kinase involved in normal development. Also quite alot of serine 
# proteaseases lots of zymogens inactive forms of enzymes which then become active 

# Plot for LOC100119822	for MSTRG.4798, protein kinase DC2 which is dependent upon cellular levelas of 
# cAMP

PLot_means_2("MSTRG.4798",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100119822')

PLot_means_2("MSTRG.4798",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100119822')

PLot_means_2("MSTRG.4798",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100119822')

# All of these were hits for neurotransmitter uptake
# plot for LOC100120350, MSTRG.6539 a carcinine transporter-like genes 
# look at http://europepmc.org/articles/PMC3029318 in drosophilla used for the recyling of the 
# neurotransmitter histamine which is released from photoreceptors. 
## otentiall worth talking about for the paper

PLot_means_2("MSTRG.6539",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100120350')

PLot_means_2("MSTRG.6539",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100120350')

PLot_means_2("MSTRG.6539",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100120350')


# plot for "LOC100120401"	"MSTRG.6518"  organic cation transporter protein-like

PLot_means_2("MSTRG.6518",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100120401')

PLot_means_2("MSTRG.6518",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100120401')

PLot_means_2("MSTRG.6518",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100120401')



# plot for "LOC100119949"	"MSTRG.6756"	 putative transporter SVOPL found in acrosomal vesicle

PLot_means_2("MSTRG.6756",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100119949')

PLot_means_2("MSTRG.6756",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100119949')

PLot_means_2("MSTRG.6756",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100119949')



# plot for "LOC100122992"	"MSTRG.9140"  synaptic vesicle glycoprotein 2B-like important for 
# cellular calcium homeostasis iea 

PLot_means_2("MSTRG.9140",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100122992')

PLot_means_2("MSTRG.9140",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100122992')

PLot_means_2("MSTRG.9140",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100122992')



# plot for 'LOC100118508' MSTRG.1883 another ATP-binding cassette sub-family G member 1 involved in 
# cholesterol homeostasis and efflux

PLot_means_2("MSTRG.1883",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100118508')

PLot_means_2("MSTRG.1883",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100118508')

PLot_means_2("MSTRG.1883",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100118508')

# plot for LOC100115434 'MSTRG.7709' NPC intracellular cholesterol transporter 2 again cholesterol 
# efflux and homeostasis

PLot_means_2("MSTRG.7709",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100115434')

PLot_means_2("MSTRG.7709",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100115434')

PLot_means_2("MSTRG.7709",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100115434')


# plot for "LOC100116121"	"MSTRG.13487" Scavenger receptor class B member 1 again cholesterol efflux
# and homeostasis

PLot_means_2("MSTRG.13487",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100116121')

PLot_means_2("MSTRG.13487",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100116121')

PLot_means_2("MSTRG.13487",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100116121')



# plot for LOC100113870"	"MSTRG.10420" GTP-binding protein Rheb homolog

# "SP97"	"MSTRG.904"	

PLot_means_2("MSTRG.904",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'SP97')


PLot_means_2("MSTRG.904",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'SP97')

PLot_means_2("MSTRG.904",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'SP97')


# "SP33"	"MSTRG.1829"

PLot_means_2("MSTRG.1829",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'SP33')


PLot_means_2("MSTRG.1829",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'SP33')

PLot_means_2("MSTRG.1829",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'SP33')


# "SP76"	"MSTRG.4565"	

PLot_means_2("MSTRG.4565",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'SP76')


PLot_means_2("MSTRG.4565",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'SP76')

PLot_means_2("MSTRG.4565",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'SP76')


# "SP82"	"MSTRG.4991"

PLot_means_2("MSTRG.4991",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'SP82')


PLot_means_2("MSTRG.4991",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'SP82')

PLot_means_2("MSTRG.4991",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'SP82')


######################################################################
######################################################################
### Genes that are DE and altspliced

# Plot of LOC100117537 which is MSTRG.5493, rRNA 2'-O-methyltransferase fibrillarin and has go term for snoRNA 
# processing and histone glutamite methylation

PLot_means_2("MSTRG.5493",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100117537')


PLot_means_2("MSTRG.5493",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100117537')

PLot_means_2("MSTRG.5493",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100117537')

# plot LOC103315597 ,  putative helicase MOV-10

# LOC100121509 increased expression with oviposition causes increase in serine metabolism

# LOC100123700 increase in negative regulation of lipid storage (energy for sperm)

PLot_means_2("MSTRG.5493",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100117537')


PLot_means_2("MSTRG.5493",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100117537')

PLot_means_2("MSTRG.5493",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100117537')


# LOC100118359 same increase glycoprotein transport activity

# See oxyreductase activity which is also important for sperm longevity 

# Increase in expression of on particular transcript it looks like of 
# LOC100123818 a phosphoserine phosphatase which is MSTRG.3612 inhibited by calcium ions

PLot_means_2("MSTRG.3612",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100123818')


PLot_means_2("MSTRG.3612",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100123818')

PLot_means_2("MSTRG.3612",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100123818 ')

# Also see decrease in SP47 

# Also see LOC100120817 with MSTRG.12779 is the glucose dehydrogenase which was talked about in both
# both 2015 and 2013 plos paper looks good might be worth plotting in paper

PLot_means_2("MSTRG.12779",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100120817')


PLot_means_2("MSTRG.12779",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100120817')

PLot_means_2("MSTRG.12779",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100120817')


# PLot for LOC100113806  which is MSTRG.9685 and comes up as Major royal jelly protein 1 in our 
# trinotate annotation but comes out as 5 or 2 depending which annotation you use

PLot_means_2("MSTRG.9685",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100113806')


PLot_means_2("MSTRG.9685",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100113806')

PLot_means_2("MSTRG.9685",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100113806')


# Plot for LOC100678877, MSTRG.9327, which is involved in calciumn bonding and lipase activity need to look at 

PLot_means_2("MSTRG.9327",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100678877')

PLot_means_2("MSTRG.9327",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100678877')

PLot_means_2("MSTRG.9327",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100678877')


# Plot for LOC100118614, MSTRG.4203,which is the same with calcium ion bonding activity as well as lipase 

PLot_means_2("MSTRG.4203",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100118614')


PLot_means_2("MSTRG.4203",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100118614')

PLot_means_2("MSTRG.4203",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100118614')


# Plot for LOC100113822 ,MSTRG.11875, which is involved in Calcium binding and is Glycerol-3-phosphate dehydrogenase
# Calcium binding enhances the activity of enzymes Look at this for ideas https://en.wikipedia.org/wiki/GAPDHS

PLot_means_2("MSTRG.11875",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100113822')


PLot_means_2("MSTRG.11875",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100113822')

PLot_means_2("MSTRG.11875",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100113822')

# PLot for LOC100119497 which is a multidrug resistance-associated protein 4-like with a CTCF transporter
# region has trnasmembrane suport 

# Plot for "LOC100123700"	"MSTRG.2226" which is ATP-binding cassette sub-family G member 4-like and 
# involved in capacitation which is semen mediated activatino of sperm motility by transporting cholestrol

PLot_means_2("MSTRG.2226",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100123700')


PLot_means_2("MSTRG.2226",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100123700')

PLot_means_2("MSTRG.2226",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100123700')

# Plot "LOC100118359"	"MSTRG.4500" which is another ATP-binding cassette and potentialy involved in 
# involved in capacitation which is semen mediated activatino of sperm motility by transporting cholestrol

PLot_means_2("MSTRG.4500",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "control",
             labelTranscripts = T , TITLE = 'LOC100118359')


PLot_means_2("MSTRG.4500",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "fresh",
             labelTranscripts = T , TITLE = 'LOC100118359')

PLot_means_2("MSTRG.4500",gown = bg_filter_2,groupvar = 'host_type', meas = "FPKM"
             ,colorby = c('transcript',"exon") ,groupname = "previously parasitised",
             labelTranscripts = T , TITLE = 'LOC100118359')


# Plot "LOC100121381"	"MSTRG.1312" which is Proton-coupled amino acid transporter-like protein pathetic
# and cellular componennt of endosome




######################################################################
######################################################################
### Genes Just DE 


# LOC100117520 which is EF-hand calcium-binding domain-containing protein 1-like which is 
# pH-dependent Ca2+ sensor required to activate the CatSper channel, a complex involved in sperm 
# cell hyperactivation. Sperm cell hyperactivation is needed for sperm motility which is essential 
# late in the preparation of sperm for fertilization. Associates with the CatSper complex via direct 
# interaction with CATSPERZ, and senses intracellular Ca2+. Together with CATSPERZ, associates with 
# the CatSper channel pore and is required for the two-row structure of each single CatSper channel
# We see an increase in this gene expression also use to regulate flagellated sperm activity found
# on the motile cilium the flagella


# Also see lots of terms for the regulation of calcium ions so cheack out.  
# MAPK phosporylation also involved in the activation of the sperm motility look up, see changes in 
# splicing of 

# LOC103317423 putative ankyrin repeat protein RF_0381 inolved in calcium and cardiac muscle also
# downregulated from trinotate as top hit for human ankyrin 2 also dowregulated look at ankryin 
# downregulated cuses atrial vefib

# LOC100679655 serine/threonine-protein phosphatase 6 regulatory ankyrin
# repeat subunit A-like [ Nasonia vitripennis (jewel wasp) ] see a decrease in this gene expression
# for go term regulation of cardiac muscle contraction by regulation of the release 
# of sequestered calcium ion, idea that a reduction in regulation of Ca results in increase into 
# Ca into cytosol

# LOC103317969 putative ankyrin repeat protein RF_0381 has a decrease in expression important for chanels
# that regulate clacium uptake therfore reduction in expression result in increased extracellular 
# calcium comes up as ankyrin 3 and ankyrin 2

# LOC100678467 uncharacterized LOC100678467 has more ankyrin repeats also shows down regulation
# top hit as Serine/threonine-protein kinase from trinotate

# Upregulation of LOC100119062 fez family zinc finger protein 1

# Oxygen reductase highly expressed as well

# LOC100679003 gamma-aminobutyric acid receptor-associated protein cluster GABA receptors by mediating
# interactions with the cytoskeleton 

# LOC100123558 AMP deaminase 2 removale of oxeygen free radical upregulated oviposition

# LOC100123633 Myosin light chain 

# LOC100677929 synaptic vesicle glycoprotein 2B-like which is found in the acrosomal vesicle and is 
# for neurotransmitter uptake linked with GABA https://www.ncbi.nlm.nih.gov/pmc/articles/PMC4893657/
# also important for Ca relaese https://www.ncbi.nlm.nih.gov/pubmed/10624962/

# LOC100122803 synaptic vesicle glycoprotein 2B-like which is found in the acrosomal vesicle and is
# like the other vesicle found in acroomal vesicle

# And another LOC100123034 synaptic vesicle glycoprotein 2B-like gene all are upregulated in ovipositing
# induviduals and all SVAB like 

# LOC100118311 is Protein spinster homolog 1 and is upregulated in oviposition and hit with this
# sphingosine-1-phosphate receptor signaling pathway and sphingolipid transporter activity which 
# https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3984488/

# LOC103317747 which is Solute carrier family 52, riboflavin transporter is upregulated in ovipositing

# LOC100121689 which is A-kinase anchor protein 9 

# LOC100679142 which is Pacifastin-like protease inhibitor cvp4 upregulated

# LOC100123161 which is Pacifastin-like protease inhibitor cvp4 upregulated

# LOC100117523 which is Papilin and endopeptidase inhibitor specifically trypsin upregulated

# LOC100122505 which is Antitrypsin from Bombyx upregulated

