
######################################################################
######################################################################
### Figures sccript Differential expression


######################################################################
######################################################################
### Reading in the data 

source("Scripts/RNA_Seq_Data_cleaning_prep.R")

######################################################################
######################################################################
### Loading in the packages


if (!require("ggplot2")) {
  install.packages("ggplot2", dependencies = TRUE)
  library(ggplot2)
}

if (!require("gridExtra")) {
  install.packages("gridExtra", dependencies = TRUE)
  library(gridExtra)
}

if (!require("Cairo")) {
  install.packages("Cairo", dependencies = TRUE)
  library(Cairo)
}

######################################################################
######################################################################
### Initial plots and investigating the data

new_position_theme <- theme(legend.position = c(0.80, 0.80) , 
                            panel.border = element_blank(), panel.grid.major = element_blank(),
                            panel.grid.minor = element_blank(), panel.background = element_blank(),
                            axis.line = element_line(colour = "grey"))

## Initial pca plot 


# getting the % of variance

# this function is taken from the Git hub for sleuth 
spread_abundance_by <- function(abund, var, which_order) {
  # var <- lazyeval::lazy(var)
  abund <- data.table::as.data.table(abund)
  var_spread <- data.table::dcast(abund, target_id ~ sample, value.var = var)
  # there is a discrepancy between data table's sorting of character vectors
  # and how tidyr previously (or the order function) sorts character vectors
  # so next step is needed to make sure the order is correct
  var_spread <- var_spread[order(var_spread$target_id), ]
  var_spread <- as.data.frame(var_spread, stringsAsFactors = FALSE)
  rownames(var_spread) <- var_spread$target_id
  var_spread["target_id"] <- NULL
  result <- as.matrix(var_spread)
  
  result[, which_order, drop = FALSE]
}

# Now using the code from the plot_variance function to get the pc1 and 2 % variance explained

mat <- spread_abundance_by(Nas_sleuth_obj$obs_norm_filt, 'est_counts')

pca_calc <- prcomp(t(mat), scale. = F) #PCA calculations

#computation
eigenvalues <- (pca_calc$sdev) ^ 2
var_explained <- eigenvalues * 100 / sum(eigenvalues)
var_explained2 <- var_explained

# Creating the PCA plot

Nas1_PCA_foundress_counts <- plot_pca(Nas_sleuth_obj, color_by = 'treatment', pc_x = 1 ,pc_y = 2, text_labels = F , units = "est_counts") +
  new_position_theme +
  ggtitle('Gene data from 2018 study (Head)') + 
  theme(plot.title = element_text(lineheight=0.8,hjust = 0.5 , size = 15)) +
  labs(x = paste('PC1 (',round(var_explained[1],digits = 2),'%)'),
       y = paste('PC2 (',round(var_explained[2],digits = 2),'%)'))
  
  
pdf("Figures/Nas1_foundress_PCA.pdf")
Nas1_PCA_foundress_counts
dev.off()

# Looking at the PCA plot loadings

plot_loadings(Nas_sleuth_obj, pc_input = 1)

# Plotting the bootstraps of the transcript causing the 3 highest loading in 
# PCA1

plot_bootstrap(Nas_sleuth_obj, 'XM_001607338.4', color_by = 'treatment') +
  new_position_theme

plot_bootstrap(Nas_sleuth_obj, 'XM_016989104.1', color_by = 'treatment') +
  new_position_theme

plot_bootstrap(Nas_sleuth_obj, 'NM_001170908.1', color_by = 'treatment') +
  new_position_theme

### PCA for second data set 

# plot for counts

# getting the % of variance

# this function is taken from the Git hub for sleuth 
spread_abundance_by <- function(abund, var, which_order) {
  # var <- lazyeval::lazy(var)
  abund <- data.table::as.data.table(abund)
  var_spread <- data.table::dcast(abund, target_id ~ sample, value.var = var)
  # there is a discrepancy between data table's sorting of character vectors
  # and how tidyr previously (or the order function) sorts character vectors
  # so next step is needed to make sure the order is correct
  var_spread <- var_spread[order(var_spread$target_id), ]
  var_spread <- as.data.frame(var_spread, stringsAsFactors = FALSE)
  rownames(var_spread) <- var_spread$target_id
  var_spread["target_id"] <- NULL
  result <- as.matrix(var_spread)
  
  result[, which_order, drop = FALSE]
}

# Now using the code from the plot_variance function to get the pc1 and 2 % variance explained

mat <- spread_abundance_by(Nas_sleuth_obj_2$obs_norm_filt, 'est_counts')

pca_calc <- prcomp(t(mat), scale. = F) #PCA calculations

#computation
eigenvalues <- (pca_calc$sdev) ^ 2
var_explained <- eigenvalues * 100 / sum(eigenvalues)
var_explained2 <- var_explained


Nas2_PCA_hosttype_counts <- plot_pca(Nas_sleuth_obj_2,color_by = "host_type", text_labels =F , frame = T) +
   new_position_theme +
  ggtitle('Gene data from 2015 study (Whole body)') + 
  theme(plot.title = element_text(lineheight=.8, hjust = 0.5)) +
  labs(x = paste('PC1 (',round(var_explained[1],digits = 2),'%)'),
       y = paste('PC2 (',round(var_explained[2],digits = 2),'%)'))

pdf("Figures/Nas2_host_PCA.pdf")
Nas2_PCA_hosttype_counts
dev.off()

# plot for tpm

plot_pca(Nas_sleuth_obj_2,color_by = "host_type", text_labels =T, units = 'tpm') +
  new_position_theme

# ploting the loadings for the second data set

plot_loadings(Nas_sleuth_obj_2, pc_input = 1)

plot_loadings(Nas_sleuth_obj_2,pc_input = 1,units = 'tpm')

plot_loadings(Nas_sleuth_obj_2,pc_input = 2,units = 'tpm')

# Plotting the boostraps of the transcripts causing 3 highest loadings
# in PCA1 of second data set for counts

plot_bootstrap(Nas_sleuth_obj_2, 'XM_008209982.2', color_by = "host_type") +
  new_position_theme

plot_bootstrap(Nas_sleuth_obj_2, 'XM_001600254.4', color_by = "host_type") +
  new_position_theme

plot_bootstrap(Nas_sleuth_obj_2, 'XM_001607338.4', color_by = "host_type") +
  new_position_theme

# Doing the same for tpm

plot_bootstrap(Nas_sleuth_obj_2, 'XR_001729383.1',color_by = "host_type",units = 'tpm')

#

### Setting up in a grid 

Gene_dif_PCA <- grid.arrange(Nas1_PCA_foundress_counts,Nas2_PCA_hosttype_counts)

ggsave('Figures/Gene_Dif_PCA.png', plot = Gene_dif_PCA , device = 'png', scale = 1.4)

cairo_ps(filename = 'Figures/Gene_Dif_PCA.eps' )

######################################################################
######################################################################
### Getting plots for induvidual genes













