#!/bin/bash

#PBS -N Hisat2_alternative_splice
#PBS -l walltime=15:00:00
#PBS -l vmem=100gb
#PBS -m bea
#PBS -M aj258@le.ac.uk
#PBS -l nodes=1:ppn=10
 cd $PBS_O_WORKDIR

module load hisat2/2.1.0

date
mkdir aligned

# We need to run the command for each pair of fastq commands, so look for the
# first of each pair
for sample in *1_trimmed_paired.fq.gz  
 do  

# From it, extract the common bit from the pair of files names, using
# sed to replace R1_001.fastq.gz with nothing.  This command 'echoes' the
# sample variable, and pipes it with the | character into the sed command 
# which process it

   describer=$(echo ${sample} | sed -e 's/1_trimmed_paired.fq.gz//')  

# and from this look for the bit that goes RNA_** and pull that out to use as the
# root of the output filenames
#   root=$(echo ${sample} | sed -e 's/.*\(WTCHG_.........\).*/\1/' )

#  printf and echo do much the same except printf can include newlines

#   printf "\nAligning ${root}\n"
	
#  Then create a command which we can show and run.  Note no spaces on either side of 
#  the = sign, and make sure the editor does not put in smart, handled, quotes
#  instead of ordinary quotes.  Using double quotes tells bash to replace ${sample}
#  etc with the variables.
#  The -1 option is the first of the two fats files, which we found originally
#  The -2 is the second fast file which we can produce from the cut down version
#  of the first
#  The -S file is the name of the output file, for which we use the core bit
#  of the filename.  
#  The 2> bit at the end means that we pipe the standard error (stderr) to a log file
#  with the same ${root}.log. (Useful to decode error messages)
	
   command="hisat2 -p 10 --novel-splicesite-outfile Novel_splice_sites -x ../Genome/GCF_000002325.3_Nvit_2.1_genomic -1 ${sample} -2 ${describer}2_trimmed_paired.fq.gz -S aligned/${describer}.sam 2>aligned/${describer}.log"

# show the command, and then do it

   echo $command
   $command
   echo "done"

 done
date

