
######################################################################
######################################################################
### Data Cleaning and preperation for differential expression

# This is to sort out the data and do any other potential cleaning or removal
# of outliying samples/genes


######################################################################
######################################################################
### Loading the packages


if (!requireNamespace("BiocManager", quietly = TRUE)){
  install.packages("BiocManager")
  BiocManager::install()
}

if(!require("sleuth")){
  BiocManager::install("pachterlab/sleuth")
  library(sleuth)
}


if (!require("sleuth")) {
  source("http://bioconductor.org/biocLite.R")
  BiocManager::install("rhdf5")
  install.packages("devtools")
  library(devtools)
  install_github("pachterlab/sleuth")
  library(sleuth)
}

if (!require("dplyr")) {
  install.packages("dplyr", dependencies = TRUE)
  library(dplyr)
}


######################################################################
######################################################################
### Loading in the data for differential expression

### Loading in the metadata from the sample runs this is obtained by 
# going to the SRA page then the SRX page click on all runs
# then get the runinfo table eg https://www.ncbi.nlm.nih.gov/Traces/study/?acc=SRP120985

sample_to_condition <- read.table('Data/SraRunTable.txt', header = TRUE,
                                  sep = '\t')

sample_to_condition <- sample_to_condition %>%
                      select(sample = Sample_Name, treatment = experimental_treatment) %>%
                      unique

# For second data set 

sample_to_condition_2 <- read.table('Data/SraRunTable_2.txt', header = T,
                                    sep = '\t')

sample_to_condition_2 <- sample_to_condition_2 %>%
                        select(sample = Sample_Name, foundress_no = foundress_number , host_type = host_type_given) %>%
                        unique 
                        
sample_to_condition_2$host_type <-  gsub("none","control",sample_to_condition_2$host_type)

# Getting the sample condition to contain the Kallistro path information

sample_ids <- dir(file.path("Kallisto/"))

sample_to_condition <- sample_to_condition %>%
  mutate(path = file.path('Kallisto',sample_ids))

# Getting samples for the second study

sample_id_2 <- dir(file.path("Kallisto_2/"))

sample_to_condition_2 <- sample_to_condition_2 %>%
    mutate(path = file.path('Kallisto_2',sample_id_2))

# Not removing sample GSM1915235 due to outlier PCA as based upon tpm

sample_to_condition_2 <- sample_to_condition_2 
  #filter(sample != "GSM1915235") 
  #filter(sample != "GSM1915238")

# looking at difference between un parasitised host and non parasitised

#sample_to_condition_2 <- sample_to_condition_2 %>%
#  filter(host_type != "none")

###  Gettting the genes associated to thier respective transcripts using gtf as nasonia not on biomart
### using the Get_gene_name.sh bash script

Trans_Gene <- read.table("Data/Gene_list")

colnames(Trans_Gene) <- c("target_id","gene_name")

Trans_Gene$target_id <- as.character(Trans_Gene$target_id)

Trans_Gene$gene_name <- as.character(Trans_Gene$gene_name)


######################################################################
######################################################################
### Creating the Sleuth object for differential expression 

### Creating the Sleuth object 

Nas_sleuth_obj <- sleuth_prep(sample_to_condition,target_mapping = Trans_Gene, aggregation_column = "gene_name",
                              extra_bootstrap_summary = TRUE ,read_bootstrap_tpm =T) 


Nas_sleuth_obj_2 <- sleuth_prep(sample_to_condition_2,target_mapping = Trans_Gene, aggregation_column = "gene_name",
                                extra_bootstrap_summary = T,read_bootstrap_tpm =T)






